#!/usr/bin/env python3

import os
import unittest
import yaml
import amulet
import sys

seconds_to_wait = 3000


class BundleTest(unittest.TestCase):
    """ Create a class for testing the charm in the unit test framework. """
    @classmethod
    def setUpClass(cls):
        """ Set up an amulet deployment using the bundle. """
        d = amulet.Deployment(series='trusty')
        d.add('ibm-xlc')
        d.add('ubuntu')
        d.relate('ibm-xlc:default', 'ubuntu:juju-info')
        d.setup(seconds_to_wait)
        d.sentry.wait(seconds_to_wait)
        cls.d = d

    def test_deployed(self):
        """ Test to see if the bundle deployed successfully. """
        self.assertTrue(self.d.deployed)
        xlc_unit = self.d.sentry['ibm-xlc'][0]
        xlc_unit.run('cd /var/lib/juju/agents/unit-ibm-xlc*/charm/files/archives;xlc hello.c -o hello')
                
        cmd = "/var/lib/juju/agents/unit-ibm-xlc*/charm/files/archives/hello"
        output, code = xlc_unit.run(cmd)
        if code != 0:
         message = 'Unable to run C Program.'
         amulet.raise_status(amulet.FAIL, msg=message)
        print('Output of simple C program is  %s' % output)
        
        xlc_unit.run('cd /var/lib/juju/agents/unit-ibm-xlc*/charm/files/archives;xlc++ hello1.cpp -o hello1')
                
        cmd1 = "/var/lib/juju/agents/unit-ibm-xlc*/charm/files/archives/hello1"
        output1, code1 = xlc_unit.run(cmd1)
        if code1 != 0:
         message1 = 'Unable to run C Program.'
         amulet.raise_status(amulet.FAIL, msg=message1)
        print('Output of simple C++ program is  %s' % output1)

        

if __name__ == '__main__':
    unittest.main()
